#
# spec file for package python-protonvpn-nm-lib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
# test suite requires network connection, you can test locally with `rpmbuild --with test`
%bcond_with test
Name:           python-protonvpn-nm-lib
Version:        3.16.0
Release:        3.3
Summary:        Proton VPN NetworkManager library
License:        GPL-3.0-or-later
Group:          Development/Languages/Python
URL:            https://github.com/ProtonVPN/protonvpn-nm-lib
Source:         https://github.com/ProtonVPN/protonvpn-nm-lib/archive/refs/tags/%{version}.tar.gz#/protonvpn-nm-lib-%{version}.tar.gz
# PATCH-FIX-UPSTREAM exclude-tests.patch gh#ProtonVPN/protonvpn-nm-lib!25 mcepl@suse.com
# Exlcude tests being grabbed by find_packeges during setup
Patch0:         exclude-tests.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyxdg}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gobject-introspection
BuildRequires:  python-rpm-macros
Requires:       NetworkManager-openvpn
Requires:       python-Jinja2
Requires:       python-dbus-python
Requires:       python-distro
Requires:       python-gobject
Requires:       python-keyring
Requires:       python-proton-client >= 0.5.0
Requires:       python-pyxdg
Requires:       python-systemd
BuildArch:      noarch
# SECTION check that all runtime requirements are available
BuildRequires:  %{python_module Jinja2}
BuildRequires:  %{python_module dbus-python}
BuildRequires:  %{python_module distro}
BuildRequires:  %{python_module gobject}
BuildRequires:  %{python_module keyring}
BuildRequires:  %{python_module proton-client >= 0.5.0}
BuildRequires:  %{python_module pyxdg}
BuildRequires:  %{python_module systemd}
BuildRequires:  NetworkManager-openvpn
# /SECTION
%if %{with test}
BuildRequires:  %{python_module pytest}
%endif
%python_subpackages

%description
The Proton VPN NetworkManager library

%prep
%autosetup -n protonvpn-nm-lib-%{version} -p1
sed -i '/addopts/d' setup.cfg

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%pytest
%endif

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/protonvpn_nm_lib
%{python_sitelib}/protonvpn_nm_lib-%{version}*-info

%changelog
* Fri Nov  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Do not (Build)Require dbus-1-x11: the dependency seems unused, as
  it's abstracted throughpython-dbus. dbus-1-x11 is scheduled for
  removal after the switch to dbus-broker.
* Wed Jan  3 2024 Dirk Müller <dmueller@suse.com>
- require setuptools
* Mon Sep 25 2023 Matej Cepl <mcepl@suse.com>
- Clean up the SPEC file
- Add exclude-tests.patch (from gh#ProtonVPN/protonvpn-nm-lib!25)
* Mon Sep 25 2023 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Update to 3.16.0
  * Fix connectivity issue if protonstatus is down
  * Update openvpn template
* Mon Nov 28 2022 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Update to 3.14.0
  * When vpn session is invalid and an api request is made, ensure that user is logged out
  * Properly handle session refresh
  * Display propper error message when unable to establish VPN tunnel
* Fri Jul  1 2022 Ben Greiner <code@bnavigator.de>
- Update to 3.11.0
  * Fix: When loading a session from keyring, update the app
    version and user agent with the current ones
- Release 3.10.0
  * Introducing Proton's refreshed look. As we continue to make
    privacy accessible to everyone, we've updated our apps to
    provide you with an even better experience with our services.
    Proton - Privacy by default
- Release 3.9.0
  * Fix: Crash when attempting to fetch netzone
  * Fix: "1000:Permission Denied" error when killswitch is enabled
- Release 3.8.0
  * Improve: Server list
  * Improve: Rename exception
  * Feature: Moderate NAT, Non Standard Ports
- Enable local (non-obs) testing when network connection is
  available
* Tue May  3 2022 Max Lin <mlin@suse.com>
- Requiring python-Jinja2 instead of python-jinja2
* Thu Mar  3 2022 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Update to 3.7.0
  * Bug fixes and improvments
* Tue Oct 26 2021 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Update to 3.6.0
  * Bug fixes and improvments
* Fri Jul 23 2021 Alexandre Vicenzi <alexandre.vicenzi@suse.com>
- Initial revision
